Data formats
============

NumLPA produces data of different categories (mainly dislocation positions, simulation results and fit results).
During development, it was considered of primary importance that the user be able to replace, edit, load and reuse this data.
This led to the data formats presented here.

.. toctree::
   :maxdepth: 2
   :caption: Contents:
   :glob:

   formats/*
